@@ -4,11 +4,11 @@ Created : 2015-03-12
 
 @author: Eric Lapouyade
 """
-__version__ = "0.19.0"
+__version__ = "0.20.0"
 
 # flake8: noqa
 from .inline_image import InlineImage
 from .listing import Listing
-from .richtext import RichText, R
+from .richtext import RichText, R, RichTextParagraph, RP
 from .subdoc import Subdoc
 from .template import DocxTemplate
